@@ -10,7 +10,7 @@ from Queue import Empty, Queue as _Queue
 
 from kombu.connection import BrokerConnection
 from kombu.entity import Exchange, Queue
-from kombu.exceptions import VersionMismatch
+from kombu.exceptions import InconsistencyError, VersionMismatch
 from kombu.messaging import Consumer, Producer
 from kombu.utils import eventio  # patch poll
 
@@ -62,9 +62,15 @@ class Client(object):
             self.sets[key] = set()
         self.sets[key].add(member)
 
+    def exists(self, key):
+        return key in self.queues or key in self.sets
+
     def smembers(self, key):
         return self.sets.get(key, set())
 
+    def srem(self, key):
+        self.sets.pop(key, None)
+
     def llen(self, key):
         return self.queues[key].qsize()
 
@@ -183,6 +189,9 @@ class Channel(redis.Channel):
     def _new_queue(self, queue, **kwargs):
         self.client._new_queue(queue)
 
+    def pipeline(self):
+        return Pipeline(Client())
+
 
 class Transport(redis.Transport):
     Channel = Channel
@@ -423,6 +432,24 @@ class test_Channel(TestCase):
             if InvalidData is not None:
                 exceptions.InvalidData = InvalidData
 
+    def test_empty_queues_key(self):
+        channel = self.channel
+        channel._in_poll = False
+        key = channel.keyprefix_queue % 'celery'
+
+        # Everything is fine, there is a list of queues.
+        channel.client.sadd(key, 'celery\x06\x16\x06\x16celery')
+        self.assertListEqual(channel.get_table('celery'),
+                             [('celery', '', 'celery')])
+
+        # ... then for some reason, the _kombu.binding.celery key gets lost
+        channel.client.srem(key)
+
+        # which raises a channel error so that the consumer/publisher
+        # can recover by redeclaring the required entities.
+        with self.assertRaises(InconsistencyError):
+            self.channel.get_table("celery")
+
 
 class test_Redis(TestCase):
 
