@@ -19,6 +19,7 @@ from anyjson import loads, dumps
 from pymongo.connection import Connection
 
 from . import virtual
+from ..exceptions import StdChannelError
 
 DEFAULT_HOST = "127.0.0.1"
 DEFAULT_PORT = 27017
@@ -93,19 +94,51 @@ class Channel(virtual.Channel):
             self._client.connection.end_request()
 
     def _open(self):
+        """
+        See mongodb uri documentation:
+        http://www.mongodb.org/display/DOCS/Connections
+        """
         conninfo = self.connection.client
-        mongoconn = Connection(host=conninfo.hostname, port=conninfo.port)
-        dbname = conninfo.virtual_host
+
+        dbname = None
+        hostname = None
+
+        if not conninfo.hostname:
+            conninfo.hostname = DEFAULT_HOST
+
+        for part in conninfo.hostname.split("/"):
+            if not hostname:
+                hostname = "mongodb://" + part
+                continue
+
+            dbname = part
+            if "?" in part:
+                # In case someone is passing options
+                # to the mongodb connection. Right now
+                # it is not permitted by kombu
+                dbname, options = part.split("?")
+                hostname += "/?" + options
+
+        # At this point we expect the hostname to be something like
+        # (considering replica set form too):
+        #
+        #   mongodb://[username:password@]host1[:port1][,host2[:port2],
+        #   ...[,hostN[:portN]]][/[?options]]
+        mongoconn = Connection(host=hostname)
         version = mongoconn.server_info()["version"]
         if tuple(map(int, version.split(".")[:2])) < (1, 3):
             raise NotImplementedError(
                 "Kombu requires MongoDB version 1.3+, but connected to %s" % (
                     version, ))
+
         if not dbname or dbname == "/":
             dbname = "kombu_default"
+
         database = getattr(mongoconn, dbname)
-        if conninfo.userid:
-            database.authenticate(conninfo.userid, conninfo.password)
+
+        # This is done by the connection uri
+        # if conninfo.userid:
+        #     database.authenticate(conninfo.userid, conninfo.password)
 
         self.db = database
         col = database.messages
@@ -178,5 +211,6 @@ class Transport(virtual.Transport):
     polling_interval = 1
     default_port = DEFAULT_PORT
     connection_errors = (errors.ConnectionFailure, )
-    channel_errors = (errors.ConnectionFailure,
+    channel_errors = (StdChannelError,
+                      errors.ConnectionFailure,
                       errors.OperationFailure, )
